==> okteta-0.26.1.tar.xz: okteta-0.26.1/libs/kasten/core/system/documentcreatemanager_p.hpp <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2006-2007,2009,2011,2019 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef KASTEN_DOCUMENTCREATEMANAGER_P_HPP
#define KASTEN_DOCUMENTCREATEMANAGER_P_HPP

// lib
#include "documentcreatemanager.hpp"

namespace Kasten {

class DocumentCreateManagerPrivate
{
public:
    explicit DocumentCreateManagerPrivate(DocumentManager* manager);

    ~DocumentCreateManagerPrivate();

public:
    bool canCreateNewFromData(const QMimeData* mimeData) const;

public:
    void createNew() const;
    void createNewFromData(const QMimeData* mimeData, bool setModified) const;

public:
    void setDocumentFactory(AbstractDocumentFactory* factory);

private:
    // unless there is a singleton
    DocumentManager* mManager;

    // temporary hack: hard coded factory for byte arrays
    AbstractDocumentFactory* mFactory = nullptr;
};

}

#endif

==> okteta_0.26.3.orig.tar.xz: okteta-0.26.3/libs/kasten/core/system/documentcreatemanager_p.hpp <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2006-2007,2009,2011,2019 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef KASTEN_DOCUMENTCREATEMANAGER_P_HPP
#define KASTEN_DOCUMENTCREATEMANAGER_P_HPP

// lib
#include "documentcreatemanager.hpp"

namespace Kasten {

class DocumentCreateManagerPrivate
{
public:
    explicit DocumentCreateManagerPrivate(DocumentManager* manager);
    DocumentCreateManagerPrivate(const DocumentCreateManagerPrivate&) = delete;

    ~DocumentCreateManagerPrivate();

public:
    DocumentCreateManagerPrivate& operator=(const DocumentCreateManagerPrivate&) = delete;

public:
    bool canCreateNewFromData(const QMimeData* mimeData) const;

public:
    void createNew() const;
    void createNewFromData(const QMimeData* mimeData, bool setModified) const;

public:
    void setDocumentFactory(AbstractDocumentFactory* factory);

private:
    // unless there is a singleton
    DocumentManager* mManager;

    // temporary hack: hard coded factory for byte arrays
    AbstractDocumentFactory* mFactory = nullptr;
};

}

#endif
